@@ -65,7 +65,6 @@ import shutil
 import tempfile
 from pathlib import Path
 
-TIMEOUT = 60 * 60
 MAX_LOC = 300
 
 
@@ -186,8 +185,6 @@ def py_to_nb(py_path, nb_path, fill_outputs=False):
                 "jupyter nbconvert --to notebook --execute --debug "
                 + str(nb_path)
                 + " --inplace"
-                + " --ExecutePreprocessor.timeout="
-                + str(TIMEOUT)
             )
         finally:
             new_files = os.listdir(parent_dir)
@@ -236,8 +233,6 @@ def nb_to_md(nb_path, md_path, img_dir, working_dir=None):
         + nb_fname
         + " --output "
         + target_md
-        + " --ExecutePreprocessor.timeout="
-        + str(TIMEOUT)
     )
     if os.path.exists(md_name + ".md"):
         success = True
@@ -570,13 +565,27 @@ def main():
                 raise ValueError(
                     f"The source filename should be a Notebook file. Got: {source}"
                 )
-            nb_to_md(source, md_path=target + ".md", img_dir=target)
+            if not target.endswith(".md"):
+                raise ValueError(
+                    f"The target filename should be a Markdown file. Got: {source}"
+                )
+            without_md = "".join(target.rsplit(".md", 1))
+            path_without_last_name = str(without_md).split(os.path.sep)[:-1]
+            img_dir = "/".join(path_without_last_name)
+            nb_to_md(source, md_path=target, img_dir=img_dir)
         if cmd == "py2md":
             if not source.endswith(".py"):
                 raise ValueError(
                     f"The source filename should be a Python file. Got: {source}"
                 )
-            py_to_md(source, nb_path=".ipynb", md_path=target+".md", img_dir=target)
+            if not target.endswith(".md"):
+                raise ValueError(
+                    f"The target filename should be a Markdown file. Got: {source}"
+                )
+            without_md = "".join(target.rsplit(".md", 1))
+            path_without_last_name = str(without_md).split(os.path.sep)[:-1]
+            img_dir = "/".join(path_without_last_name)
+            py_to_md(source, nb_path=".ipynb", md_path=target, img_dir=img_dir)
         if cmd == "py2nb":
             if not source.endswith(".py"):
                 raise ValueError(
